## distnet

![screenshot](/Documentation/Images/appearance.png)

Visualizer for tcp connections. Ports 53 and 43 should accept connections for full functionality.

[![Build Status](https://travis-ci.org/p0licat/distnet.svg?branch=develop)](https://travis-ci.org/p0licat/distnet)
[![codecov](https://codecov.io/gh/p0licat/distnet/branch/develop/graph/badge.svg)](https://codecov.io/gh/p0licat/distnet)
[![PyPI version](https://badge.fury.io/py/distnet.svg)](https://badge.fury.io/py/distnet)


## Requirements:

  Package was built for python3.4 or above. Please use `python3`

### Installation:

  `pip3 install distnet`

  `pip3 install git+https://github.com/p0licat/distnet`

### Usage:

  `python3 -m distnet -h`

  `python3 -m distnet --visual -c`
